var phidget22 = require('phidget22');

var SERVER_PORT = 5661;

function main() {

	if (process.argv.length != 3) {
		console.log('usage: node IR.js <server address>');
		process.exit(1);
	}
	var hostname = process.argv[2];

	console.log('connecting to:' + hostname);
	var conn = new phidget22.Connection(SERVER_PORT, hostname, { name: 'Server Connection', passwd: '' });
	conn.connect()
		.then(runExample)
		.catch(function (err) {
			console.error('Error running example:', err.message);
			process.exit(1);
		});
}

function runExample() {

	console.log('connected to server');
	var ch = new phidget22.IR();

	ch.onAttach = function (ch) {
		console.log(ch + ' attached');
	};

	ch.onDetach = function (ch) {
		console.log(ch + ' detached');
	};

	ch.onCode = function (code, bitCount, isRepeat) {
		var lastCode = this.getLastCode();
		console.log('code:' + code + ' (' + lastCode.code +
			') bitCount:' + bitCount + ' (' + lastCode.bitCount + ') isRepeat: ' + isRepeat);
	};

	ch.onLearn = function (code, codeInfo) {
		var encodingStr;
		var lengthStr;

		encodingStr = "";
		switch (codeInfo.encoding) {
			case phidget22.IRCodeEncoding.UNKNOWN:
				encodingStr = "UNKNOWN";
				break;
			case phidget22.IRCodeEncoding.SPACE:
				encodingStr = "SPACE";
				break;
			case phidget22.IRCodeEncoding.PULSE:
				encodingStr = "PULSE";
				break;
			case phidget22.IRCodeEncoding.BI_PHASE:
				encodingStr = "BI_PHASE";
				break;
			case phidget22.IRCodeEncoding.RC5:
				encodingStr = "RC5";
				break;
			case phidget22.IRCodeEncoding.RC6:
				encodingStr = "RC6";
				break;
			default:
				encodingStr = "Unknown";
				break;
		}
		lengthStr = "";
		switch (codeInfo.length) {
			case phidget22.IRCodeLength.UNKNOWN:
				lengthStr = "UNKNOWN";
				break;
			case phidget22.IRCodeLength.CONSTANT:
				lengthStr = "CONSTANT";
				break;
			case phidget22.IRCodeLength.VARIABLE:
				lengthStr = "VARIABLE";
				break;
			default:
				lengthStr = "Unknown";
				break;
		}

		console.log('Learned Code Info: ');
		console.log('---------------------------------------------');
		console.log('Bit Count: ' + codeInfo.bitCount);
		console.log('Encoding: ' + encodingStr);
		console.log('Length: ' + lengthStr);
		console.log('Gap: ' + codeInfo.gap)
		console.log('Trail: ' + codeInfo.trail);
		console.log('Header: ' + codeInfo.header)
		console.log('One: ' + codeInfo.one);
		console.log('Zero: ' + codeInfo.zero);
		console.log('Repeat: {');
		for (var i = 0; i < 26; i++) {
			if (codeInfo.repeat[i] == 0)
				break;
			if (i == 0)
				console.log(codeInfo.repeat[i]);
			else
				console.log(', ' + codeInfo.repeat[i]);
		}
		console.log('}');
		console.log('MinRepeat: ' + codeInfo.minRepeat);
		console.log('Toggle Mask: ' + codeInfo.toggleMask);

		console.log('Carrier Frequency: ' + codeInfo.carrierFrequency)
		console.log('Duty Cycle: ' + codeInfo.dutyCycle);
		console.log('---------------------------------------------');
	};

	ch.onRawData = function (data, length) {
		console.log("\nRaw Data:\n" + data + "\n" + length);
	}

	ch.open().then(function (ch) {
		console.log('channel open');
	}).catch(function (err) {
		console.log('failed to open the channel:' + err);
	});
}

if (require.main === module)
	main();
